/* ~Օʉ
 * Copyright (c) 2004 Kagetani Hideto
 */
#ifndef __CMDLOG_H__
#define __CMDLOG_H__

#ifdef __cplusplus
extern "C" {
#endif

extern int CreateLog(DRIVE *pReader, DRIVE *pWriter, int nWriter);

extern void CmdLog(DRIVE *drive, BYTE *cdb, DWORD buflen, BYTE reqflag,
		   int retcode);

extern int CmdLogInit(DRIVE *drive, int cmdlog_size);

extern void CmdLogFree(DRIVE *drive);

#ifdef __cplusplus
}
#endif

#endif /* !__CMDLOG_H__ */
